LBNL notebook for accelerated door sign creation

Testing information is in the tests folder.

Instructions for how to test and debug parts of the script can be found in tests/instructions.

For other advice or input, email my personal email adamhetherwick@gmail.com

08/30/2024